==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Inserir À',
	'barre_adresse' => 'Endereço',
	'barre_aide' => 'Usar atalhos de digitação para melhorar o layout',
	'barre_alignerdroite' => 'Alinhar parágrafo [/à direita/]',
	'barre_ancres' => 'Gestão de âncoras',
	'barre_barre' => 'Tachar o texto',
	'barre_bulle' => 'Bolha de ajuda',
	'barre_c_cedille_maj' => 'Inserir Ç',
	'barre_cadre' => 'Pôr em uma &lt;cadre&gt;textarea&lt;/cadre&gt;',
	'barre_caracteres' => 'Caracteres especiais',
	'barre_centrer' => '[|Centralizar|] o parágrafo',
	'barre_chercher' => 'Localizar Substituir',
	'barre_clean' => 'Limpar o código de todas as tags HTML',
	'barre_code' => 'Editar em &lt;code&gt;código&lt;/code&gt;',
	'barre_desindenter' => 'Desindentar uma lista',
	'barre_e_accent_aigu' => 'Inserir É',
	'barre_e_accent_grave' => 'Inserir È',
	'barre_ea' => 'Inserir æ',
	'barre_ea_maj' => 'Inserir Æ',
	'barre_encadrer' => '[(Enquadrar)] o parágrafo',
	'barre_eo' => 'Inserir œ',
	'barre_eo_maj' => 'Inserir Œ',
	'barre_euro' => 'Inserir €',
	'barre_exposant' => 'Pôr o texto em &lt;sup&gt;expoente&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Formatação especial',
	'barre_galerie' => 'Abrir a galeria',
	'barre_gestion_anc_bulle' => 'Bolha de ajuda da âncora',
	'barre_gestion_anc_caption' => 'Gestão de âncoras',
	'barre_gestion_anc_cible' => 'alvo da âncora',
	'barre_gestion_anc_inserer' => 'Transformar em âncora',
	'barre_gestion_anc_nom' => 'Nome da âncora',
	'barre_gestion_anc_pointer' => 'Ponteiro para uma âncora',
	'barre_gestion_caption' => 'Legenda e Resumo',
	'barre_gestion_colonne' => 'no. de colunas',
	'barre_gestion_cr_casse' => 'Diferenciar caixa alta/baixa',
	'barre_gestion_cr_changercasse' => 'Alterar caixa alta/baixa',
	'barre_gestion_cr_changercassemajuscules' => 'Transformar em caixa alta',
	'barre_gestion_cr_changercasseminuscules' => 'Transformar em caixa baixa',
	'barre_gestion_cr_chercher' => 'Buscar',
	'barre_gestion_cr_entier' => 'Palavra inteira',
	'barre_gestion_cr_remplacer' => 'Substituir',
	'barre_gestion_cr_tout' => 'Substituir tudo',
	'barre_gestion_entete' => 'Cabeçalho',
	'barre_gestion_ligne' => 'no. de linhas',
	'barre_gestion_taille' => 'Tamanho fixo',
	'barre_glossaire' => 'Referência [?glossaire] (Wikipedia)',
	'barre_gras' => 'Pôr em {{negrito}}',
	'barre_guillemets' => 'Colocar entre «aspas francesas»',
	'barre_guillemets_simples' => 'Colocar entre “aspas”',
	'barre_indenter' => 'Indentar uma lista',
	'barre_inserer_cadre' => 'Insirir código pré-formatado (framework)', # MODIF
	'barre_inserer_caracteres' => 'Inserir caracteres especiais',
	'barre_inserer_code' => 'Inserir código de informática (code)', # MODIF
	'barre_intertitre' => 'Transformar em {{{intertítulo}}}',
	'barre_italic' => 'Pôr em {itálico}',
	'barre_langue' => 'Linguagem abreviada',
	'barre_lien' => 'Transformar em [link ->http://...]',
	'barre_lien_externe' => 'Link externo',
	'barre_lien_input' => 'Indique o endereço do link (pode ser uma página, como  http://qqcoisa.com.br, um endereço de email — ou, para lincar com um artigo deste site, simplesmente digite seu número.',
	'barre_liste_ol' => 'Pôr em lista numerada',
	'barre_liste_ul' => 'Pôr em lista',
	'barre_lorem_ipsum' => 'Insira um parágrafo nonono',
	'barre_lorem_ipsum_3' => 'Inserir três parágrafos nonono',
	'barre_miseenevidence' => 'Pôr o texto em [*destaque*]',
	'barre_note' => 'Transformar em [[Nota de rodapé]]',
	'barre_paragraphe' => 'Criar um parágrafo',
	'barre_petitescapitales' => 'Pôr o texto em &lt;sc&gt;versaletes&lt;/sc&gt;',
	'barre_poesie' => 'Formatar como &lt;poesie&gt;poesia&lt;/poesie&gt;',
	'barre_preview' => 'Modo previsualização',
	'barre_quote' => '<quote>Fazer uma citação</quote>',
	'barre_stats' => 'Exibir estatísticas do texto',
	'barre_tableau' => 'Inserir/modificar uma tabela (selecione antes)',

	// C
	'config_info_enregistree' => 'Configuração salva',

	// E
	'editer' => 'Editar',
	'explication_barre_outils_public' => 'Os scripts CSS e Javascript das barras de ferramentas (extensão Porte Plume) são carregadas no espaço público e permitem a utilização dessas barras nos formulários de forums, crayons públicos ou por outros plugins, se suas respectivas configurações o permitirem.',
	'explication_barre_outils_public_2' => 'Você pode optar por não carregar esses scripts para aliviar a carga de páginas públicas. Portanto, independentemente da configuração dos fóruns, crayons ou plugins, nenhuma barra de ferramentas do Porte Plume será disponibilizado automaticamente no espaço público.',

	// I
	'info_barre_outils_public' => 'Barra de ferramentas pública',
	'info_porte_plume_titre' => 'Configurar as barras de ferramentas',

	// L
	'label_barre_outils_public_non' => 'Não carregar os scripts da barra de ferramentas no espaço público',
	'label_barre_outils_public_oui' => 'Carregar os scripts da barra de ferramentas no espaço público',

	// V
	'voir' => 'Ver'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=pt_br
// ** ne pas modifier le fichier **

return [

	// B
	'barre_a_accent_grave' => 'Inserir À',
	'barre_adresse' => 'Endereço',
	'barre_aide' => 'Usar atalhos de digitação para melhorar o layout',
	'barre_alignerdroite' => 'Alinhar parágrafo [/à direita/]',
	'barre_ancres' => 'Gestão de âncoras',
	'barre_barre' => 'Tachar o texto',
	'barre_bulle' => 'Bolha de ajuda',
	'barre_c_cedille_maj' => 'Inserir Ç',
	'barre_cadre' => 'Pôr em uma &lt;cadre&gt;textarea&lt;/cadre&gt;',
	'barre_caracteres' => 'Caracteres especiais',
	'barre_centrer' => '[|Centralizar|] o parágrafo',
	'barre_chercher' => 'Localizar Substituir',
	'barre_clean' => 'Limpar o código de todas as tags HTML',
	'barre_code' => 'Editar em &lt;code&gt;código&lt;/code&gt;',
	'barre_desindenter' => 'Desindentar uma lista',
	'barre_e_accent_aigu' => 'Inserir É',
	'barre_e_accent_grave' => 'Inserir È',
	'barre_ea' => 'Inserir æ',
	'barre_ea_maj' => 'Inserir Æ',
	'barre_encadrer' => '[(Enquadrar)] o parágrafo',
	'barre_eo' => 'Inserir œ',
	'barre_eo_maj' => 'Inserir Œ',
	'barre_euro' => 'Inserir €',
	'barre_exposant' => 'Pôr o texto em &lt;sup&gt;expoente&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Formatação especial',
	'barre_galerie' => 'Abrir a galeria',
	'barre_gestion_anc_bulle' => 'Bolha de ajuda da âncora',
	'barre_gestion_anc_caption' => 'Gestão de âncoras',
	'barre_gestion_anc_cible' => 'alvo da âncora',
	'barre_gestion_anc_inserer' => 'Transformar em âncora',
	'barre_gestion_anc_nom' => 'Nome da âncora',
	'barre_gestion_anc_pointer' => 'Ponteiro para uma âncora',
	'barre_gestion_caption' => 'Legenda e Resumo',
	'barre_gestion_colonne' => 'no. de colunas',
	'barre_gestion_cr_casse' => 'Diferenciar caixa alta/baixa',
	'barre_gestion_cr_changercasse' => 'Alterar caixa alta/baixa',
	'barre_gestion_cr_changercassemajuscules' => 'Transformar em caixa alta',
	'barre_gestion_cr_changercasseminuscules' => 'Transformar em caixa baixa',
	'barre_gestion_cr_chercher' => 'Buscar',
	'barre_gestion_cr_entier' => 'Palavra inteira',
	'barre_gestion_cr_remplacer' => 'Substituir',
	'barre_gestion_cr_tout' => 'Substituir tudo',
	'barre_gestion_entete' => 'Cabeçalho',
	'barre_gestion_ligne' => 'no. de linhas',
	'barre_gestion_taille' => 'Tamanho fixo',
	'barre_glossaire' => 'Referência [?glossaire] (Wikipedia)',
	'barre_gras' => 'Pôr em {{negrito}}',
	'barre_guillemets' => 'Colocar entre «aspas francesas»',
	'barre_guillemets_simples' => 'Colocar entre “aspas”',
	'barre_indenter' => 'Indentar uma lista',
	'barre_inserer_cadre' => 'Insirir código pré-formatado (```)',
	'barre_inserer_caracteres' => 'Inserir caracteres especiais',
	'barre_inserer_code' => 'Inserir código de informática (`)',
	'barre_intertitre' => 'Transformar em {{{intertítulo}}}',
	'barre_italic' => 'Pôr em {itálico}',
	'barre_langue' => 'Linguagem abreviada',
	'barre_lien' => 'Transformar em [link ->http://...]',
	'barre_lien_externe' => 'Link externo',
	'barre_lien_input' => 'Indique o endereço do link (pode ser uma página, como  http://qqcoisa.com.br, um endereço de email — ou, para lincar com um artigo deste site, simplesmente digite seu número.',
	'barre_liste_ol' => 'Pôr em lista numerada',
	'barre_liste_ul' => 'Pôr em lista',
	'barre_lorem_ipsum' => 'Insira um parágrafo nonono',
	'barre_lorem_ipsum_3' => 'Inserir três parágrafos nonono',
	'barre_miseenevidence' => 'Pôr o texto em [*destaque*]',
	'barre_note' => 'Transformar em [[Nota de rodapé]]',
	'barre_paragraphe' => 'Criar um parágrafo',
	'barre_petitescapitales' => 'Pôr o texto em &lt;sc&gt;versaletes&lt;/sc&gt;',
	'barre_poesie' => 'Formatar como &lt;poesie&gt;poesia&lt;/poesie&gt;',
	'barre_preview' => 'Modo previsualização',
	'barre_quote' => '<quote>Fazer uma citação</quote>',
	'barre_stats' => 'Exibir estatísticas do texto',
	'barre_tableau' => 'Inserir/modificar uma tabela (selecione antes)',

	// C
	'config_info_enregistree' => 'Configuração salva',

	// E
	'editer' => 'Editar',
	'explication_barre_outils_public' => 'Os scripts CSS e Javascript das barras de ferramentas (extensão Porte Plume) são carregadas no espaço público e permitem a utilização dessas barras nos formulários de forums, crayons públicos ou por outros plugins, se suas respectivas configurações o permitirem.',
	'explication_barre_outils_public_2' => 'Você pode optar por não carregar esses scripts para aliviar a carga de páginas públicas. Portanto, independentemente da configuração dos fóruns, crayons ou plugins, nenhuma barra de ferramentas do Porte Plume será disponibilizado automaticamente no espaço público.',

	// I
	'info_barre_outils_public' => 'Barra de ferramentas pública',
	'info_porte_plume_titre' => 'Configurar as barras de ferramentas',

	// L
	'label_barre_outils_public_non' => 'Não carregar os scripts da barra de ferramentas no espaço público',
	'label_barre_outils_public_oui' => 'Carregar os scripts da barra de ferramentas no espaço público',

	// V
	'voir' => 'Ver',
];
